@@ -13,14 +13,12 @@
   # x    Private key (derived from p and s)
   # v    Password verifier
 
-from __future__ import division
 import os
 import sys
 import hashlib
 import random
 import ctypes
 import time
-import six
 
 
 _rfc5054_compat = False
@@ -56,24 +54,24 @@ _hash_map = { SHA1   : hashlib.sha1,
 
 _ng_const = (
 # 1024-bit
-(six.b('''\
+(('''\
 EEAF0AB9ADB38DD69C33F80AFA8FC5E86072618775FF3C0B9EA2314C9C256576D674DF7496\
 EA81D3383B4813D692C6E0E0D5D8E250B98BE48E495C1D6089DAD15DC7D7B46154D6B6CE8E\
 F4AD69B15D4982559B297BCF1885C529F566660E57EC68EDBC3C05726CC02FD4CBF4976EAA\
-9AFD5138FE8376435B9FC61D2FC0EB06E3'''),
-six.b("2")),
+9AFD5138FE8376435B9FC61D2FC0EB06E3''').encode('ascii'),
+b"2"),
 # 2048
-(six.b('''\
+(('''\
 AC6BDB41324A9A9BF166DE5E1389582FAF72B6651987EE07FC3192943DB56050A37329CBB4\
 A099ED8193E0757767A13DD52312AB4B03310DCD7F48A9DA04FD50E8083969EDB767B0CF60\
 95179A163AB3661A05FBD5FAAAE82918A9962F0B93B855F97993EC975EEAA80D740ADBF4FF\
 747359D041D5C33EA71D281E446B14773BCA97B43A23FB801676BD207A436C6481F1D2B907\
 8717461A5B9D32E688F87748544523B524B0D57D5EA77A2775D2ECFA032CFBDBF52FB37861\
 60279004E57AE6AF874E7303CE53299CCC041C7BC308D82A5698F3A8D0C38271AE35F8E9DB\
-FBB694B5C803D89F7AE435DE236D525F54759B65E372FCD68EF20FA7111F9E4AFF73'''),
-six.b("2")),
+FBB694B5C803D89F7AE435DE236D525F54759B65E372FCD68EF20FA7111F9E4AFF73''').encode('ascii'),
+b"2"),
 # 4096
-(six.b('''\
+(('''\
 FFFFFFFFFFFFFFFFC90FDAA22168C234C4C6628B80DC1CD129024E08\
 8A67CC74020BBEA63B139B22514A08798E3404DDEF9519B3CD3A431B\
 302B0A6DF25F14374FE1356D6D51C245E485B576625E7EC6F44C42E9\
@@ -92,10 +90,10 @@ E0FD108E4B82D120A92108011A723C12A787E6D788719A10BDBA5B26\
 04DE8EF92E8EFC141FBECAA6287C59474E6BC05D99B2964FA090C3A2\
 233BA186515BE7ED1F612970CEE2D7AFB81BDD762170481CD0069127\
 D5B05AA993B4EA988D8FDDC186FFB7DC90A6C08F4DF435C934063199\
-FFFFFFFFFFFFFFFF'''),
-six.b("5")),
+FFFFFFFFFFFFFFFF''').encode('ascii'),
+b"5"),
 # 8192
-(six.b('''\
+(('''\
 FFFFFFFFFFFFFFFFC90FDAA22168C234C4C6628B80DC1CD129024E08\
 8A67CC74020BBEA63B139B22514A08798E3404DDEF9519B3CD3A431B\
 302B0A6DF25F14374FE1356D6D51C245E485B576625E7EC6F44C42E9\
@@ -132,8 +130,8 @@ B7C5DA76F550AA3D8A1FBFF0EB19CCB1A313D55CDA56C9EC2EF29632\
 0846851DF9AB48195DED7EA1B1D510BD7EE74D73FAF36BC31ECFA268\
 359046F4EB879F924009438B481C6CD7889A002ED5EE382BC9190DA6\
 FC026E479558E4475677E9AA9E3050E2765694DFC81F56E880B96E71\
-60C980DD98EDD3DFFFFFFFFFFFFFFFFF'''),
-six.b('13'))
+60C980DD98EDD3DFFFFFFFFFFFFFFFFF''').encode('ascii'),
+b'13')
 )
 
 
@@ -289,8 +287,8 @@ def calculate_x( hash_class, dest, salt, username, password ):
     username = username.encode() if hasattr(username, 'encode') else username
     password = password.encode() if hasattr(password, 'encode') else password
     if _no_username_in_x:
-        username = six.b('')
-    up = hash_class(username + six.b(':') + password).digest()
+        username = b''
+    up = hash_class(username + b':' + password).digest()
     H_bn_str( hash_class, dest, salt, up )
     BN_set_flags(dest, BN_FLG_CONSTTIME)
 
@@ -333,7 +331,7 @@ def HNxorg( hash_class, N, g ):
     hN = hash_class( bN.raw ).digest()
     hg = hash_class( b''.join([ b'\0'*padding, bg.raw ]) ).digest()
 
-    return six.b( ''.join( chr( six.indexbytes(hN, i) ^ six.indexbytes(hg, i) ) for i in range(0,len(hN)) ) )
+    return ( ''.join( chr( hN[i] ^ hg[i] ) for i in range(0,len(hN)) ) ).encode('latin1')
 
 
 def get_ngk( hash_class, ng_type, n_hex, g_hex, ctx ):
@@ -385,7 +383,7 @@ def create_salted_verification_key( username, password, hash_alg=SHA1, ng_type=N
 
 
 
-class Verifier (object):
+class Verifier:
     def __init__(self,  username, bytes_s, bytes_v, bytes_A=None, hash_alg=SHA1, ng_type=NG_2048, n_hex=None, g_hex=None, bytes_b=None, k_hex=None):
         if ng_type == NG_CUSTOM and (n_hex is None or g_hex is None):
             raise ValueError("Both n_hex and g_hex are required when ng_type = NG_CUSTOM")
@@ -515,7 +513,7 @@ class Verifier (object):
         self.H_AMK = calculate_H_AMK( self.hash_class, self.A, self.M, self.K )
 
 
-class User (object):
+class User:
     def __init__(self, username, password, hash_alg=SHA1, ng_type=NG_2048, n_hex=None, g_hex=None, bytes_a=None, bytes_A=None, k_hex=None):
         if ng_type == NG_CUSTOM and (n_hex is None or g_hex is None):
             raise ValueError("Both n_hex and g_hex are required when ng_type = NG_CUSTOM")
