@@ -238,7 +238,9 @@ def calculate_M( hash_class, N, g, I, s, A, B, K ):
     h = hash_class()
     h.update( HNxorg( hash_class, N, g ) )
     h.update( hash_class(I).digest() )
-    h.update( long_to_bytes(s) )
+    if isinstance(s, six.integer_types):
+        s = long_to_bytes(s)
+    h.update( s )
     h.update( long_to_bytes(A) )
     h.update( long_to_bytes(B) )
     h.update( K )
@@ -255,14 +257,14 @@ def calculate_H_AMK( hash_class, A, M, K ):
 
 
 
-class Verifier (object):
+class Verifier:
 
     def __init__(self, username, bytes_s, bytes_v, bytes_A=None, hash_alg=SHA1, ng_type=NG_2048, n_hex=None, g_hex=None, bytes_b=None, k_hex=None):
         if ng_type == NG_CUSTOM and (n_hex is None or g_hex is None):
             raise ValueError("Both n_hex and g_hex are required when ng_type = NG_CUSTOM")
-        if bytes_b and len(bytes_b) != 32:
-            raise ValueError("32 bytes required for bytes_b")
-        self.s = bytes_to_long(bytes_s)
+        if bytes_b and len(bytes_b) != 256:
+            raise ValueError("256 bytes required for bytes_b")
+        self.s = bytes_s
         self.v = bytes_to_long(bytes_v)
         self.I = username
         self.K = None
@@ -289,7 +291,7 @@ class Verifier (object):
             if bytes_b:
                 self.b = bytes_to_long(bytes_b)
             else:
-                self.b = get_random_of_length( 32 )
+                self.b = get_random_of_length( 256 )
             self.B = (k*self.v + pow(g, self.b, N)) % N
 
 
@@ -313,7 +315,7 @@ class Verifier (object):
         if self.safety_failed:
             return None,None
         else:
-            return (long_to_bytes(self.s), long_to_bytes(self.B))
+            return (self.s, long_to_bytes(self.B))
 
     # returns H_AMK on success, None on failure
     def verify_session(self, user_M, bytes_A=None):
@@ -344,12 +346,12 @@ class Verifier (object):
 
 
 
-class User (object):
+class User:
     def __init__(self, username, password, hash_alg=SHA1, ng_type=NG_2048, n_hex=None, g_hex=None, bytes_a=None, bytes_A=None, k_hex=None):
         if ng_type == NG_CUSTOM and (n_hex is None or g_hex is None):
             raise ValueError("Both n_hex and g_hex are required when ng_type = NG_CUSTOM")
-        if bytes_a and len(bytes_a) != 32:
-            raise ValueError("32 bytes required for bytes_a")
+        if bytes_a and len(bytes_a) != 256:
+            raise ValueError("256 bytes required for bytes_a")
         N,g        = get_ng( ng_type, n_hex, g_hex )
         hash_class = _hash_map[ hash_alg ]
         if k_hex is None:
@@ -362,7 +364,7 @@ class User (object):
         if bytes_a:
             self.a = bytes_to_long(bytes_a)
         else:
-            self.a = get_random_of_length( 32 )
+            self.a = get_random_of_length( 256 )
         if bytes_A:
             self.A = bytes_to_long(bytes_A)
         else:
@@ -402,7 +404,7 @@ class User (object):
     # Returns M or None if SRP-6a safety check is violated
     def process_challenge(self, bytes_s, bytes_B):
 
-        self.s = bytes_to_long( bytes_s )
+        self.s = bytes_s
         self.B = bytes_to_long( bytes_B )
 
         N = self.N
